@@ -305,9 +305,9 @@ class ServerlessClamscan(
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="defsAccessLogsBucket")
-    def defs_access_logs_bucket(self) -> typing.Optional[monocdk.aws_s3.Bucket]:
+    def defs_access_logs_bucket(self) -> typing.Optional[monocdk.aws_s3.IBucket]:
         '''Conditional: The Bucket for access logs for the virus definitions bucket if logging is enabled (defsBucketAccessLogsConfig).'''
-        return typing.cast(typing.Optional[monocdk.aws_s3.Bucket], jsii.get(self, "defsAccessLogsBucket"))
+        return typing.cast(typing.Optional[monocdk.aws_s3.IBucket], jsii.get(self, "defsAccessLogsBucket"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="errorDeadLetterQueue")
@@ -343,7 +343,7 @@ class ServerlessClamscanLoggingProps:
     def __init__(
         self,
         *,
-        logs_bucket: typing.Optional[typing.Union[builtins.bool, monocdk.aws_s3.Bucket]] = None,
+        logs_bucket: typing.Optional[typing.Union[builtins.bool, monocdk.aws_s3.IBucket]] = None,
         logs_prefix: typing.Optional[builtins.str] = None,
     ) -> None:
         '''Interface for ServerlessClamscan Virus Definitions S3 Bucket Logging.
@@ -360,10 +360,10 @@ class ServerlessClamscanLoggingProps:
     @builtins.property
     def logs_bucket(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, monocdk.aws_s3.Bucket]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, monocdk.aws_s3.IBucket]]:
         '''Destination bucket for the server access logs (Default: Creates a new S3 Bucket for access logs ).'''
         result = self._values.get("logs_bucket")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, monocdk.aws_s3.Bucket]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, monocdk.aws_s3.IBucket]], result)
 
     @builtins.property
     def logs_prefix(self) -> typing.Optional[builtins.str]:
